# $Id: Coverage.pm 910 2008-08-06 02:34:52Z gene $

package Chess::Coverage;
our $VERSION = '0.04_1';

1;

__END__

=head1 NAME

Chess::Coverage - Expose chess ply potential energy - MOVED

=head1 PLEASE SEE

L<Chess::Rep::Coverage>

=head1 AUTHOR

Gene Boggs E<lt>gene@cpan.orgE<gt>

=head1 COPYRIGHT

Copyright 2007-2008, Gene Boggs.

This code is licensed under the same terms as Perl itself.

=cut
